Module sorting

Module sorting 

Functions

bubble_sort
bucket_sort
Sort a slice using bucket sort algorithm.
cocktail_shaker_sort
comb_sort
counting_sort
In place counting sort for collections of u32 O(n + maxval) in time, where maxval is the biggest value an input can possibly take O(maxval) in memory u32 is chosen arbitrarly, a counting sort probably should’nt be used on data that requires bigger types.
generic_counting_sort
Generic implementation of a counting sort for all usigned types
gnome_sort
heap_sort
Sort a mutable slice using heap sort.
insertion_sort
Sorts a mutable slice using in-place insertion sort algorithm.
is_sorted
merge_sort
odd_even_sort
partition
quick_sort
radix_sort
Sorts the elements of arr in-place using radix sort.
selection_sort
shell_sort
stooge_sort
tim_sort