Functions
- bubble_
sort - bucket_
sort - Sort a slice using bucket sort algorithm.
- cocktail_
shaker_ sort - comb_
sort - counting_
sort - In place counting sort for collections of u32 O(n + maxval) in time, where maxval is the biggest value an input can possibly take O(maxval) in memory u32 is chosen arbitrarly, a counting sort probably should’nt be used on data that requires bigger types.
- generic_
counting_ sort - Generic implementation of a counting sort for all usigned types
- gnome_
sort - heap_
sort - Sort a mutable slice using heap sort.
- insertion_
sort - Sorts a mutable slice using in-place insertion sort algorithm.
- is_
sorted - merge_
sort - odd_
even_ sort - partition
- quick_
sort - radix_
sort - Sorts the elements of
arrin-place using radix sort. - selection_
sort - shell_
sort - stooge_
sort - tim_
sort